@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/catless/Zircon/lib/RCS/Channel.tcl,v $
-# $Date: 1998/08/19 12:17:29 $
-# $Revision: 1.18.1.176 $
+# $Source: /home/nlfm/Zircon/lib/RCS/Channel.tcl,v $
+# $Date: 1998/11/13 12:21:38 $
+# $Revision: 1.18.1.177 $
 #
 #
 package provide zircon 1.18
@@ -1432,6 +1432,27 @@ proc channel_nickChange {this usr nnk} {
     }
 }
 #
+proc nop {args} { return 1}
+#
+proc cpriv {chan op spk menu x} {
+    return [cpriv1 $chan $op $spk [winfo name [$menu entrycget $x -menu]]]
+}
+#
+proc cpriv1 {chan op spk usr2} {
+    set op1 [$chan isOp $usr2]
+    set spk1 [$chan isSpeaker $usr2]
+    if {$op} {
+        if {$op1} { return 1}
+	return 2
+    } elseif {$spk} {
+        if {$op1} { return 0}
+	if {$spk1} { return 1 }
+	return 2
+    }
+    if {$op1 || $spk1} { return 0 }
+    return 1
+}
+#
 proc sc {a b} { switch -- $a $b {return 1} ; return 0}
 #
 proc scl {a b} { switch -- $a [string tolower $b] {return 1} ; return 0 }
@@ -1440,6 +1461,8 @@ proc sortIns {chan nk usr w} {
     set last [$w index last]
     makeUserMenu $chan $w.$usr $usr
     if {![$chan nosort]} {
+    	set op [$chan isOp $usr]
+	set spk [$chan isSpeaker $usr]
 	if {[$chan nocase]} {
 	    set cnk [string tolower $nk]
 	    set fn sc
@@ -1447,10 +1470,24 @@ proc sortIns {chan nk usr w} {
 	    set cnk $nk
 	    set fn scl
 	}
+	if {[$chan nopriv]} {
+	    set fn1 nop
+	} {
+	    set fn1 cpriv
+	}
 	for {set x 4} {$x <= $last} {incr x} {
-	    if {[$fn $cnk [$w entrycget $x -label]] < 0} {
-		$w insert $x cascade -label $nk -menu $w.$usr
-		return $x
+	    switch [$fn1 $chan $op $spk $w $x] {
+	      0 { }
+	      1 {
+	    	    if {[$fn $cnk [$w entrycget $x -label]] < 0} {
+			$w insert $x cascade -label $nk -menu $w.$usr
+			return $x
+	    	    }
+	        }
+	      2 {
+		    $w insert $x cascade -label $nk -menu $w.$usr
+		    return $x
+	       }
 	    }
 	}
     }
@@ -1461,6 +1498,7 @@ proc sortIns {chan nk usr w} {
 proc wsortIns {chan win un usr args} {
     set wnk $win.$usr
     set fn name
+    set fn1 cpriv1
     switch nil $chan {
 	if {[[$usr net] ircIIops]} {
 	    set txt [lindex $args 0]$un
@@ -1475,6 +1513,9 @@ proc wsortIns {chan win un usr args} {
 	    set un [string tolower $un]
 	    set fn lname
 	}
+	if {[$chan nopriv]} {
+	    set fn1 nop
+	}
     }
     set top text
     set wd [$win cget -width]
@@ -1498,12 +1539,24 @@ proc wsortIns {chan win un usr args} {
     switch {} $wd {} default { $wnk configure -width $wd }
     $wnk configure -menu [makeUserMenu $chan $wnk.menu $usr]
     if {$srt} {
+        set op [$chan isOp $usr]
+	set spk [$chan isSpeaker $usr]
 	set y 1
 	while {![catch {set x [$win window cget 1.$y -window]}]} {
 	    switch {} $x {} default {
-		if {[string compare $un [[winfo name $x] $fn]] < 0} {
+	    	set u2 [winfo name $x]
+		switch [$fn1 $chan $op $spk $u2] {
+		0 { }
+		1 {
+		    if {[string compare $un [$u2 $fn]] < 0} {
+		        $win window create [$win index $x] -window $wnk -padx 0
+		        return
+		    }
+		  }
+		2 {
 		    $win window create [$win index $x] -window $wnk -padx 0
 		    return
+		   }
 		}
 	    }
 	    incr y
@@ -1836,13 +1889,13 @@ proc channel_pack {this where} {
 #
 proc channel_unpack {this where} {
     upvar #0 $where$this new
-    foreach prop {name open close jump join draw quiet menu msg \
-      history closetime key icon logfile nocase keep sys scrollback} {
+    upvar #0 Configure.Channel config
+    foreach prop [array names config] {
 	$this configure -$prop $new($prop)
     }
-    foreach prop {foreground background} {
-	switch {} $new($prop) {} default {$this configure -$prop $new($prop)}
-    }
+#    foreach prop {foreground background} {
+#	switch {} $new($prop) {} default {$this configure -$prop $new($prop)}
+#    }
     unset new
 }
 #
