@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Chat.tcl,v $
-# $Date: 1998/09/02 12:57:32 $
-# $Revision: 1.18.1.46 $
+# $Date: 1998/11/06 10:07:30 $
+# $Revision: 1.18.1.47 $
 #
 package provide zircon 1.18
 #
@@ -162,13 +162,9 @@ proc chat_save {this desc} { mncSave $desc $this defChat DChat }
 proc ChatServer {usr nk} {
     set net [$usr net]
     upvar #0 AChat$net AChat
-    if {[catch {socket -server "acceptChat $usr" 0} sock]} { error $sock }
-    if {[catch {fconfigure $sock -sockname} xx]} {
-	error "Cannot get port for server - $xx"
-    }
-    set AChat($usr) $sock
+    foreach {AChat($usr) cinfo} [makeServer "acceptChat $usr"] break
     $usr ref
-    $net CTCP DCC $nk "CHAT chat [ipPack [ipAddress]] [lindex $xx 2]"
+    $net CTCP DCC $nk "CHAT chat [ipPack [ipAddress]] [lindex $cinfo 2]"
 }
 #
 proc chat_heal {this} {
