@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Monitor.tcl,v $
-# $Date: 1998/05/28 09:33:18 $
-# $Revision: 1.18.1.18 $
+# $Source: /home/nlfm/Zircon/lib/RCS/Monitor.tcl,v $
+# $Date: 1998/11/13 12:21:43 $
+# $Revision: 1.18.1.19 $
 #
 package provide zircon 1.18
 #
@@ -81,12 +81,13 @@ proc monitor_show {this} {
 #
 proc monitor_delete {this} {
     switch {} [set wn [$this wid]] {} default {
-        set w [$wn name]
-        catch {
-	    foreach x [winfo children $w.usr] {catch {[winfo name $x] deref}}
-	    destroy $w
-        }
-        $wn deregister $this
+        if {![catch {$wn name} w]} {
+            catch {
+	        foreach x [winfo children $w.usr] {catch {[winfo name $x] deref}}
+	        destroy $w
+            }
+            $wn deregister $this
+	}
     }
     uplevel #0 unset $this
     rename $this {}
