@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Net.tcl,v $
-# $Date: 1998/11/06 10:07:34 $
-# $Revision: 1.18.1.159 $
+# $Date: 1998/11/13 12:21:45 $
+# $Revision: 1.18.1.160 $
 #
 package provide zircon 1.18
 #
@@ -319,9 +319,9 @@ proc net_startIRC {this srv args} {
 		update
 		set rtc 2
 	    } {
+		$ctl setQuit abort "$this abort $sock"
 		$this fast
 		fileevent $sock writable "sconf $sock [list $enc]; $this afterCon $sock"
-		$ctl setQuit abort "$this abort $sock"
 		set connected($this) 0
 		vwait connected($this)
 		set rtc $connected($this)
@@ -339,8 +339,8 @@ proc net_startIRC {this srv args} {
 		retitleFrame [MainInfo] [$this info] [$this name] 1
 	    } {
 	    	$this inform {Connection attempt aborted}
-		retitleFrame [MainControl] $this [$this name]
-		retitleFrame [MainInfo] [$this info] [$this name]
+		retitleFrame [MainControl] $this [$this name] 1
+		retitleFrame [MainInfo] [$this info] [$this name] 1
 	    }
 	    switch {} [$srv nextPort] break
 	}
@@ -357,6 +357,8 @@ proc net_startIRC {this srv args} {
 }
 #
 proc net_abort {this sock} {
+zshow "abort called $sock"
+    fileevent $sock writable {}
     close $sock
     uplevel #0 set connected($this) 3
 }
