@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Util.tcl,v $
-# $Date: 1998/10/08 09:37:57 $
-# $Revision: 1.18.1.79 $
+# $Date: 1998/11/06 10:07:39 $
+# $Revision: 1.18.1.80 $
 #
 package provide zircon 1.18
 #
@@ -315,7 +315,7 @@ proc ipAddress {} {
 	vwait hostIPaddress
 	catch {close $sock}
 	catch {close $sock2}
-	switch $hostIPaddress {0.0.0.0} - {127.0.0.1} {
+	switch -- $hostIPaddress {0.0.0.0} - {127.0.0.1} {
 	    tkwait [mkDialog {} .@ip {IP Number} \
 	      {Please enter the IP number for your host} \
 	      [list [list {IP Number} {}]] [list ok "set hostIPaddress"]]
@@ -324,14 +324,22 @@ proc ipAddress {} {
     return $hostIPaddress
 }
 #
-proc acceptCon {cmd p1 p2} { fileevent $p1 readable $cmd }
+#proc acceptCon {cmd p1 p2} { fileevent $p1 readable $cmd }
 #
-proc server {cmd} {
-    set fd [socket -server "acceptCon {$cmd}" 0]
-    if {[catch {fconfigure $fd -sockname} xx]} {
+#proc server {cmd} {
+#    set fd [socket -server "acceptCon {$cmd}" 0]
+#    if {[catch {fconfigure $fd -sockname} xx]} {
+#	error "Cannot get port for server - $xx"
+#   }
+#    return [list $fd [lindex $xx 2]]
+#}
+#
+proc makeServer {cmd} {
+    if {[catch {socket -server $cmd 0} sock]} { error $sock }
+    if {[catch {fconfigure $sock -sockname} xx]} {
 	error "Cannot get port for server - $xx"
     }
-    return [list $fd [lindex $xx 2]]
+    return [list $sock $xx]
 }
 #
 proc zping {res} {
